summaryrefslogtreecommitdiffstats
path: root/ksysv/kscroller.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/kscroller.h')
-rw-r--r--ksysv/kscroller.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ksysv/kscroller.h b/ksysv/kscroller.h
index 9bcddab..77a78f9 100644
--- a/ksysv/kscroller.h
+++ b/ksysv/kscroller.h
@@ -22,10 +22,10 @@ public:
/**
* Constructor.
*
* @param tqparent the tqparent of this widget (passed on as ususal).
* @param name the name of this widget (as above).
*/
- KScroller (TQWidget* tqparent = 0L, const char* name = 0L);
+ KScroller (TQWidget* parent = 0L, const char* name = 0L);
/**
* Destructor.
@@ -22,10 +22,10 @@ public:
* Constructor.
*
- * @param tqparent the tqparent of this widget (passed on as ususal).
+ * @param parent the parent of this widget (passed on as ususal).
* @param name the name of this widget (as above).
*/